@@ -46,7 +46,7 @@
 
 #include "e-cal-backend-caldav.h"
 
-#define d(x)
+#define d(x) x
 
 /* in seconds */
 #define DEFAULT_REFRESH_TIME 60
@@ -115,6 +115,10 @@ struct _ECalBackendCalDAVPrivate {
 	gboolean disposed;
 
 	icaltimezone *default_zone;
+
+	/* support for 'getctag' extension */
+	gboolean ctag_supported;
+	gchar *ctag;
 };
 
 /* ************************************************************************* */
@@ -542,14 +546,15 @@ parse_status_node (xmlNodePtr node, guint *status_code)
 static char *
 xp_object_get_string (xmlXPathObjectPtr result)
 {
-	char *ret;
+	char *ret = NULL;
 
-	if (result == NULL || result->type != XPATH_STRING) {
-		return NULL;
+	if (result == NULL)
+		return ret;
+
+	if (result->type == XPATH_STRING) {
+		ret = g_strdup ((char *) result->stringval);
 	}
 
-	ret = g_strdup ((char *) result->stringval);
-
 	xmlXPathFreeObject (result);
 	return ret;
 }
@@ -559,24 +564,25 @@ xp_object_get_string (xmlXPathObjectPtr result)
 static char *
 xp_object_get_href (xmlXPathObjectPtr result)
 {
-	char *ret;
+	char *ret = NULL;
 	char *val;
 
-	if (result == NULL || result->type != XPATH_STRING) {
-		return NULL;
+	if (result == NULL)
+		return ret;
+
+	if (result->type == XPATH_STRING) {
+		val = (char *) result->stringval;
+
+		if ((ret = g_strrstr (val, "/")) == NULL) {
+			ret = val;
+		} else {
+			ret++; /* skip the unwanted "/" */
+		}
+
+		ret = g_strdup (ret);
+		d(g_debug ("found href: %s", ret));
 	}
 
-	val = (char *) result->stringval;
-
-	if ((ret = g_strrstr (val, "/")) == NULL) {
-		ret = val;
-	} else {
-		ret++; /* skip the unwanted "/" */
-	}
-
-	ret = g_strdup (ret);
-	d(g_debug ("found href: %s", ret));
-
 	xmlXPathFreeObject (result);
 	return ret;
 }
@@ -585,17 +591,18 @@ xp_object_get_href (xmlXPathObjectPtr result)
 static char *
 xp_object_get_etag (xmlXPathObjectPtr result)
 {
-	char *ret;
+	char *ret = NULL;
 	char *str;
 
-	if (result == NULL || result->type != XPATH_STRING) {
-		return NULL;
+	if (result == NULL)
+		return ret;
+
+	if (result->type == XPATH_STRING) {
+		str = (char *) result->stringval;
+
+		ret = quote_etag (str);
 	}
 
-	str = (char *) result->stringval;
-
-	ret = quote_etag (str);
-
 	xmlXPathFreeObject (result);
 	return ret;
 }
@@ -604,20 +611,20 @@ static guint
 xp_object_get_status (xmlXPathObjectPtr result)
 {
 	gboolean res;
-	guint    ret;
+	guint    ret = 0;
 
+	if (result == NULL)
+		return ret;
 
-	if (result == NULL || result->type != XPATH_STRING) {
-		return 0;
-	}
+	if (result->type == XPATH_STRING) {
+		res = soup_headers_parse_status_line ((char *) result->stringval,
+							NULL,
+							&ret,
+							NULL);
 
-	res = soup_headers_parse_status_line ((char *) result->stringval,
-					      NULL,
-					      &ret,
-					      NULL);
-
-	if (res != TRUE) {
-		ret = 0;
+		if (res != TRUE) {
+			ret = 0;
+		}
 	}
 
 	xmlXPathFreeObject (result);
@@ -628,14 +635,15 @@ xp_object_get_status (xmlXPathObjectPtr result)
 static int
 xp_object_get_number (xmlXPathObjectPtr result)
 {
-	int ret;
+	int ret = -1;
 
-	if (result == NULL || result->type != XPATH_STRING) {
-		return -1;
+	if (result == NULL)
+		return ret;
+
+	if (result->type == XPATH_STRING) {
+		ret = result->boolval;
 	}
 
-	ret = result->boolval;
-
 	xmlXPathFreeObject (result);
 	return ret;
 }
@@ -647,7 +655,8 @@ xp_object_get_number (xmlXPathObjectPtr result)
 #define XPATH_GETETAG_STATUS "string(/D:multistatus/D:response[%d]/D:propstat/D:prop/D:getetag/../../D:status)"
 #define XPATH_GETETAG "string(/D:multistatus/D:response[%d]/D:propstat/D:prop/D:getetag)"
 #define XPATH_CALENDAR_DATA "string(/D:multistatus/D:response[%d]/C:calendar-data)"
-
+#define XPATH_GETCTAG_STATUS "string(/D:multistatus/D:response/D:propstat/D:prop/CS:getctag/../../D:status)"
+#define XPATH_GETCTAG "string(/D:multistatus/D:response/D:propstat/D:prop/CS:getctag)"
 
 typedef struct _CalDAVObject CalDAVObject;
 
@@ -750,6 +759,8 @@ parse_report_response (SoupMessage *soup_message, CalDAVObject **objs, int *len)
 	}
 
 out:
+	if (result != NULL)
+		xmlXPathFreeObject (result);
 	xmlXPathFreeContext (xpctx);
 	xmlFreeDoc (doc);
 	return res;
@@ -907,8 +918,8 @@ caldav_generate_uri (ECalBackendCalDAV *cbdav, const char *target)
 
 	priv = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);
 
-	/* priv->uri must NOT have trailing slash */
-	uri = g_strconcat (priv->uri, "/" , target, NULL);
+	/* priv->uri *have* trailing slash already */
+	uri = g_strconcat (priv->uri, target, NULL);
 
 	return uri;
 }
@@ -969,6 +980,136 @@ caldav_server_open_calendar (ECalBackendCalDAV *cbdav)
 	return GNOME_Evolution_Calendar_NoSuchCal;
 }
 
+/* returns whether was able to read new ctag from the server's response */
+static gboolean
+parse_getctag_response (SoupMessage *message, gchar **new_ctag)
+{
+	xmlXPathContextPtr xpctx;
+	xmlDocPtr          doc;
+	gboolean           res = FALSE;
+
+	g_return_val_if_fail (message != NULL, FALSE);
+	g_return_val_if_fail (new_ctag != NULL, FALSE);
+
+	doc = xmlReadMemory (message->response_body->data,
+			     message->response_body->length,
+			     "response.xml",
+			     NULL,
+			     0);
+
+	if (doc == NULL) {
+		return FALSE;
+	}
+
+	xpctx = xmlXPathNewContext (doc);
+	xmlXPathRegisterNs (xpctx, (xmlChar *) "D", (xmlChar *) "DAV:");
+	xmlXPathRegisterNs (xpctx, (xmlChar *) "CS", (xmlChar *) "http://calendarserver.org/ns/");
+
+	if (xp_object_get_status (xpath_eval (xpctx, XPATH_GETCTAG_STATUS)) == 200) {
+		char *txt = xp_object_get_string (xpath_eval (xpctx, XPATH_GETCTAG));
+
+		if (txt && *txt) {
+			int len = strlen (txt);
+
+			if (*txt == '\"' && len > 2 && txt [len - 1] == '\"') {
+				/* dequote */
+				*new_ctag = g_strndup (txt + 1, len - 2);
+			} else {
+				*new_ctag = txt;
+				txt = NULL;
+			}
+
+			res = (*new_ctag) != NULL;
+		}
+
+		g_free (txt);
+	}
+
+	xmlXPathFreeContext (xpctx);
+	xmlFreeDoc (doc);
+
+	return res;
+}
+
+/* Returns whether calendar changed on the server. This works only when server
+   supports 'getctag' extension. */
+static gboolean
+check_calendar_changed_on_server (ECalBackendCalDAV *cbdav)
+{
+	ECalBackendCalDAVPrivate *priv;
+	xmlOutputBufferPtr   	  buf;
+	SoupMessage              *message;
+	xmlDocPtr		  doc;
+	xmlNodePtr           	  root, node;
+	xmlNsPtr		  ns, nsdav;
+	gboolean 		  result = TRUE;
+
+	g_return_val_if_fail (cbdav != NULL, TRUE);
+
+	priv   = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);
+
+	/* no support for 'getctag', thus update cache */
+	if (!priv->ctag_supported)
+		return TRUE;
+
+	doc = xmlNewDoc ((xmlChar *) "1.0");
+	root = xmlNewNode (NULL, (xmlChar *) "propfind");
+	nsdav = xmlNewNs (root, (xmlChar *) "DAV:", NULL);
+	ns = xmlNewNs (root, (xmlChar *) "http://calendarserver.org/ns/", (xmlChar *) "CS");
+
+	node = xmlNewTextChild (root, nsdav, (xmlChar *) "prop", NULL);
+	node = xmlNewTextChild (node, nsdav, (xmlChar *) "getctag", NULL);
+	xmlSetNs (node, ns);
+
+	buf = xmlAllocOutputBuffer (NULL);
+	xmlNodeDumpOutput (buf, doc, root, 0, 1, NULL);
+	xmlOutputBufferFlush (buf);
+
+	/* Prepare the soup message */
+	message = soup_message_new ("PROPFIND", priv->uri);
+	soup_message_headers_append (message->request_headers,
+				     "User-Agent", "Evolution/" VERSION);
+	soup_message_headers_append (message->request_headers,
+				     "Depth", "0");
+
+	soup_message_set_request (message,
+				  "application/xml",
+				  SOUP_MEMORY_COPY,
+				  (char *) buf->buffer->content,
+				  buf->buffer->use);
+
+	/* Send the request now */
+	send_and_handle_redirection (priv->session, message, NULL);
+
+	/* Clean up the memory */
+	xmlOutputBufferClose (buf);
+	xmlFreeDoc (doc);
+
+	/* Check the result */
+	if (message->status_code != 207) {
+		/* does not support it, but report calendar changed to update cache */
+		priv->ctag_supported = FALSE;
+	} else {
+		char *ctag = NULL;
+
+		if (parse_getctag_response (message, &ctag)) {
+			if (ctag && priv->ctag && g_str_equal (ctag, priv->ctag)) {
+				/* ctag is same, no change in the calendar */
+				result = FALSE;
+				g_free (ctag);
+			} else {
+				g_free (priv->ctag);
+				priv->ctag = ctag;
+			}
+		} else {
+			priv->ctag_supported = FALSE;
+		}
+	}
+
+	g_object_unref (message);
+
+	return result;
+}
 
 static gboolean
 caldav_server_list_objects (ECalBackendCalDAV *cbdav, CalDAVObject **objs, int *len)
@@ -1004,7 +1145,18 @@ caldav_server_list_objects (ECalBackendCalDAV *cbdav, CalDAVObject **objs, int *
 	xmlSetProp (node, (xmlChar *) "name", (xmlChar *) "VCALENDAR");
 
 	sn = xmlNewTextChild (node, nscd, (xmlChar *) "comp-filter", NULL);
-	xmlSetProp (sn, (xmlChar *) "name", (xmlChar *) "VEVENT");
+	switch (e_cal_backend_get_kind (E_CAL_BACKEND (cbdav))) {
+		default:
+		case ICAL_VEVENT_COMPONENT:
+			xmlSetProp (sn, (xmlChar *) "name", (xmlChar *) "VEVENT");
+			break;
+		case ICAL_VJOURNAL_COMPONENT:
+			xmlSetProp (sn, (xmlChar *) "name", (xmlChar *) "VJOURNAL");
+			break;
+		case ICAL_VTODO_COMPONENT:
+			xmlSetProp (sn, (xmlChar *) "name", (xmlChar *) "VTODO");
+			break;
+	}
 	/* ^^^ add timerange for performance?  */
 
 
@@ -1242,31 +1394,34 @@ synchronize_object (ECalBackendCalDAV *cbdav,
 	bkend = E_CAL_BACKEND (cbdav);
 
 	if (kind == ICAL_VCALENDAR_COMPONENT) {
-
 		kind = e_cal_backend_get_kind (bkend);
 		subcomp = icalcomponent_get_first_component (icomp, kind);
 
-		comp = e_cal_component_new ();
-		res = e_cal_component_set_icalcomponent (comp,
-						   icalcomponent_new_clone (subcomp));
-		if (res == TRUE) {
-			icaltimezone *zone = icaltimezone_new ();
-
-			e_cal_component_set_href (comp, object->href);
-			e_cal_component_set_etag (comp, object->etag);
-
-			for (subcomp = icalcomponent_get_first_component (icomp, ICAL_VTIMEZONE_COMPONENT);
-			    subcomp;
-			    subcomp = icalcomponent_get_next_component (icomp, ICAL_VTIMEZONE_COMPONENT)) {
-				/* copy timezones of the component to our cache to have it available later */
-				if (icaltimezone_set_component (zone, subcomp))
-					e_cal_backend_cache_put_timezone (priv->cache, zone);
-			}
-
-			icaltimezone_free (zone, TRUE);
+		if (!subcomp) {
+			res = FALSE;
 		} else {
-			g_object_unref (comp);
-			comp = NULL;
+			comp = e_cal_component_new ();
+			res = e_cal_component_set_icalcomponent (comp,
+						   icalcomponent_new_clone (subcomp));
+			if (res == TRUE) {
+				icaltimezone *zone = icaltimezone_new ();
+
+				e_cal_component_set_href (comp, object->href);
+				e_cal_component_set_etag (comp, object->etag);
+
+				for (subcomp = icalcomponent_get_first_component (icomp, ICAL_VTIMEZONE_COMPONENT);
+				    subcomp;
+				    subcomp = icalcomponent_get_next_component (icomp, ICAL_VTIMEZONE_COMPONENT)) {
+					/* copy timezones of the component to our cache to have it available later */
+					if (icaltimezone_set_component (zone, subcomp))
+						e_cal_backend_cache_put_timezone (priv->cache, zone);
+				}
+
+				icaltimezone_free (zone, TRUE);
+			} else {
+				g_object_unref (comp);
+				comp = NULL;
+			}
 		}
 	} else {
 		res = FALSE;
@@ -1318,6 +1473,11 @@ synchronize_cache (ECalBackendCalDAV *cbdav)
 	len    = 0;
 	sobjs  = NULL;
 
+	if (!check_calendar_changed_on_server (cbdav)) {
+		/* no changes on the server, no update required */
+		return;
+	}
+
 	res = caldav_server_list_objects (cbdav, &sobjs, &len);
 
 	if (res == FALSE) {
@@ -1588,13 +1748,11 @@ initialize_backend (ECalBackendCalDAV *cbdav)
 		}
 
 		priv->uri = g_strconcat (proto, uri + 9, NULL);
-
 	} else {
-
 		priv->uri = g_strdup (uri);
 	}
 
-	/* remove trailing slashes */
+	/* remove trailing slashes... */
 	len = strlen (priv->uri);
 	while (len--) {
 		if (priv->uri[len] == '/') {
@@ -1604,8 +1762,32 @@ initialize_backend (ECalBackendCalDAV *cbdav)
 		}
 	}
 
+	/* ...and append exactly one slash */
+	if (priv->uri && *priv->uri) {
+		char *tmp = priv->uri;
+
+		priv->uri = g_strconcat (priv->uri, "/", NULL);
+
+		g_free (tmp);
+	}
+
 	if (priv->cache == NULL) {
-		priv->cache = e_cal_backend_cache_new (priv->uri, E_CAL_SOURCE_TYPE_EVENT);
+		ECalSourceType source_type;
+
+		switch (e_cal_backend_get_kind (E_CAL_BACKEND (cbdav))) {
+			default:
+			case ICAL_VEVENT_COMPONENT:
+				source_type = E_CAL_SOURCE_TYPE_EVENT;
+				break;
+			case ICAL_VTODO_COMPONENT:
+				source_type = E_CAL_SOURCE_TYPE_TODO;
+				break;
+			case ICAL_VJOURNAL_COMPONENT:
+				source_type = E_CAL_SOURCE_TYPE_JOURNAL;
+				break;
+		}
+
+		priv->cache = e_cal_backend_cache_new (priv->uri, source_type);
 
 		if (priv->cache == NULL) {
 			result = GNOME_Evolution_Calendar_OtherError;
@@ -1650,6 +1832,11 @@ caldav_do_open (ECalBackendSync *backend,
 
 	g_mutex_lock (priv->lock);
 
+	/* let it decide the 'getctag' extension availability again */
+	g_free (priv->ctag);
+	priv->ctag = NULL;
+	priv->ctag_supported = TRUE;
+
 	if (priv->loaded != TRUE) {
 		priv->ostatus = initialize_backend (cbdav);
 	}
@@ -1844,7 +2031,7 @@ caldav_create_object (ECalBackendSync  *backend,
 	}
 
 	/* Set the created and last modified times on the component */
-	current = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
+	current = icaltime_from_timet (time (NULL), 0);
 	e_cal_component_set_created (comp, &current);
 	e_cal_component_set_last_modified (comp, &current);
 
@@ -1927,7 +2114,7 @@ caldav_modify_object (ECalBackendSync  *backend,
 	}
 
 	/* Set the last modified time on the component */
-	current = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
+	current = icaltime_from_timet (time (NULL), 0);
 	e_cal_component_set_last_modified (comp, &current);
 
 	/* sanitize the component*/
@@ -2101,7 +2288,6 @@ extract_objects (icalcomponent       *icomp,
 						   ekind);
 
 	while (scomp) {
-
 		/* Remove components from toplevel here */
 		*objects = g_list_prepend (*objects, scomp);
 		icalcomponent_remove_component (icomp, scomp);
@@ -2135,7 +2321,7 @@ process_object (ECalBackendCalDAV   *cbdav,
 	backend = E_CAL_BACKEND (cbdav);
 
 	/* ctime, mtime */
-	now = icaltime_current_time_with_zone (icaltimezone_get_utc_timezone ());
+	now = icaltime_from_timet (time (NULL), 0);
 	e_cal_component_set_created (ecomp, &now);
 	e_cal_component_set_last_modified (ecomp, &now);
 
@@ -2309,8 +2495,7 @@ caldav_receive_objects (ECalBackendSync *backend,
 		return GNOME_Evolution_Calendar_InvalidObject;
 	}
 
-	/* FIXME: use the e_cal_backend_xxx_kind call here */
-	kind = ICAL_VEVENT_COMPONENT;
+	kind = e_cal_backend_get_kind (E_CAL_BACKEND (backend));
 	status = extract_objects (icomp, kind, &objects);
 
 	if (status != GNOME_Evolution_Calendar_Success) {
@@ -2395,7 +2580,22 @@ caldav_get_default_object (ECalBackendSync  *backend,
 	ECalComponent *comp;
 
  	comp = e_cal_component_new ();
-	e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
+
+ 	switch (e_cal_backend_get_kind (E_CAL_BACKEND (backend))) {
+ 	case ICAL_VEVENT_COMPONENT:
+ 		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_EVENT);
+ 		break;
+ 	case ICAL_VTODO_COMPONENT:
+ 		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_TODO);
+ 		break;
+ 	case ICAL_VJOURNAL_COMPONENT:
+ 		e_cal_component_set_new_vtype (comp, E_CAL_COMPONENT_JOURNAL);
+ 		break;
+ 	default:
+ 		g_object_unref (comp);
+		return GNOME_Evolution_Calendar_ObjectNotFound;
+ 	}
+
  	*object = e_cal_component_get_as_string (comp);
  	g_object_unref (comp);
 
@@ -2833,6 +3033,9 @@ e_cal_backend_caldav_finalize (GObject *object)
 	cbdav = E_CAL_BACKEND_CALDAV (object);
 	priv = E_CAL_BACKEND_CALDAV_GET_PRIVATE (cbdav);
 
+	g_free (priv->ctag);
+	priv->ctag = NULL;
+
 	g_mutex_free (priv->lock);
 	g_cond_free (priv->cond);
 	g_cond_free (priv->slave_gone_cond);
@@ -2864,6 +3067,10 @@ e_cal_backend_caldav_init (ECalBackendCalDAV *cbdav)
 	priv->do_synch = FALSE;
 	priv->loaded   = FALSE;
 
+	/* Thinks the 'getctag' extension is available the first time, but unset it when realizes it isn't. */
+	priv->ctag_supported = TRUE;
+	priv->ctag = NULL;
+
 	priv->lock = g_mutex_new ();
 	priv->cond = g_cond_new ();
 	priv->slave_gone_cond = g_cond_new ();
