@@ -36,375 +36,9 @@
 
 #include "camel-debug.h"
 
-/* how long to wait before invoking sync on the file; in miliseconds */
-#define SYNC_TIMEOUT 5000
-
-static sqlite3_vfs *old_vfs = NULL;
-
-GStaticRecMutex only_once_lock = G_STATIC_REC_MUTEX_INIT;
-GStaticRecMutex sync_queue_lock = G_STATIC_REC_MUTEX_INIT;
-#define LockQueue()   g_static_rec_mutex_lock   (&sync_queue_lock)
-#define UnlockQueue() g_static_rec_mutex_unlock (&sync_queue_lock)
-
-/* 'sync_queue' is using keys sqlite3_file to sync_queue_data structures.
-   Access to this is guarded with LockQueue/UnlockQueue function. */
-static GHashTable *sync_queue = NULL;
-
-typedef struct _sync_queue_data {
-	guint timeout_source; /* id of the source */
-	GThread *running_thread;
-
-	int sync_flags; 
-} sync_queue_data;
-
-struct CamelSqlite3File
-{
-	sqlite3_file parent;
-	sqlite3_file *old_vfs_file; /* pointer to old_vfs' file */
-};
-
-static int
-call_old_file_Sync (sqlite3_file *pFile, int flags)
-{
-	struct CamelSqlite3File *cFile;
-
-	g_return_val_if_fail (old_vfs != NULL, SQLITE_ERROR);
-	g_return_val_if_fail (pFile != NULL, SQLITE_ERROR);
-
-	cFile = (struct CamelSqlite3File *)pFile;
-	g_return_val_if_fail (cFile->old_vfs_file->pMethods != NULL, SQLITE_ERROR);
-	return cFile->old_vfs_file->pMethods->xSync (cFile->old_vfs_file, flags);
-}
-
-static gboolean prepare_to_run_sync_in_thread (gpointer pFile);
-
-static gpointer
-run_sync_in_thread (gpointer pFile)
-{
-	int sync_flags = 0;
-	sync_queue_data *data;
-
-	g_return_val_if_fail (pFile != NULL, NULL);
-	g_return_val_if_fail (sync_queue != NULL, NULL);
-
-	LockQueue ();
-	data = g_hash_table_lookup (sync_queue, pFile);
-	if (data) {
-		/* sync_flags can change while we are running */
-		sync_flags = data->sync_flags;
-		data->sync_flags = 0;
-	}
-	UnlockQueue ();
-
-	/* this should not happen, once we are in a thread, the datas are ours */
-	g_return_val_if_fail (data != NULL, NULL);
-
-	/* do the sync itself, but do not block the sync_queue;
-	   any error here is silently ignored. */
-	call_old_file_Sync (/*sqlite3_file*/pFile, sync_flags);
-
-	LockQueue ();
-	if (data->timeout_source == -1) {
-		/* new sync request arrived meanwhile, indicate thread finished... */
-		data->running_thread = NULL;
-		/* ...and reschedule */
-		data->timeout_source = g_timeout_add (SYNC_TIMEOUT, prepare_to_run_sync_in_thread, pFile);
-	} else {
-		/* remove it from a sync_queue and free memory */
-		g_hash_table_remove (sync_queue, pFile);
-		g_free (data);
-	}
-	UnlockQueue ();
-
-	return NULL;
-}
-
-static gboolean
-prepare_to_run_sync_in_thread (gpointer pFile)
-{
-	sync_queue_data *data;
-
-	g_return_val_if_fail (pFile != NULL, FALSE);
-	g_return_val_if_fail (sync_queue != NULL, FALSE);
-
-	LockQueue ();
-
-	data = g_hash_table_lookup (sync_queue, pFile);
-	/* check if still tracking this file and if didn't get rescheduled */
-	if (data && data->timeout_source == g_source_get_id (g_main_current_source ())) {
-		/* run the thread */
-		data->running_thread = g_thread_create (run_sync_in_thread, pFile, TRUE, NULL);
-		data->timeout_source = 0;
-	}
-
-	UnlockQueue ();
-
-	return FALSE;
-}
-
-/*
-   Adds sync on this file to the queue. Flags are just bit-OR-ed,
-   which will not hopefully hurt. In case the file is waiting for
-   it's sync, we just postpone it once again.
-   In case file is syncing just in call of this, we schedule other
-   sync after that.
- */
-static void
-queue_sync (sqlite3_file *pFile, int flags)
-{
-	sync_queue_data *data;
-
-	g_return_if_fail (pFile != NULL);
-	g_return_if_fail (flags != 0);
-
-	LockQueue ();
-
-	if (!sync_queue)
-		sync_queue = g_hash_table_new (g_direct_hash, g_direct_equal);
-
-	data = g_hash_table_lookup (sync_queue, pFile);
-	if (data) {
-		/* There is a sync request for this file already. */
-		if (data->running_thread) {
-			/* -1 indicates to reschedule after the actual sync finishes */
-			data->timeout_source = -1;
-			/* start with new flags - thread set it to 0; next time just add others */
-			data->sync_flags = data->sync_flags | flags;
-		} else {
-			data->sync_flags = data->sync_flags | flags;
-
-			/* reschedule */
-			g_source_remove (data->timeout_source);
-			data->timeout_source = g_timeout_add (SYNC_TIMEOUT, prepare_to_run_sync_in_thread, pFile);
-		}
-	} else {
-		data = g_malloc0 (sizeof (sync_queue_data));
-		data->sync_flags = flags;
-		data->running_thread = NULL;
-		data->timeout_source = g_timeout_add (SYNC_TIMEOUT, prepare_to_run_sync_in_thread, pFile);
-
-		g_hash_table_insert (sync_queue, pFile, data);
-	}
-
-	UnlockQueue ();
-}
-
-/*
-   If file is not in a queue, it does nothing, otherwise it removes
-   it from a queue, and calls sync immediately.
-   If file is syncing at the moment, it waits until the previous sync finishes.
- */
-static void
-dequeue_sync (sqlite3_file *pFile)
-{
-	sync_queue_data *data;
-
-	g_return_if_fail (pFile != NULL);
-
-	LockQueue ();
-
-	if (!sync_queue) {
-		/* closing file which wasn't requested to sync, and none
-		   before it too. */
-		UnlockQueue ();
-		return;
-	}
-
-	data = g_hash_table_lookup (sync_queue, pFile);
-	if (data) {
-		int sync_flags = data->sync_flags;
-
-		if (data->timeout_source) {
-			if (data->timeout_source != -1)
-				g_source_remove (data->timeout_source);
-			data->timeout_source = 0;
-		}
-
-		if (data->running_thread) {
-			GThread *thread = data->running_thread;
-
-			/* do not do anything later */
-			data = NULL;
-
-			/* unlock here, thus the thread can hold the lock again */
-			UnlockQueue ();
-
-			/* it's running at the moment, wait for a finish.
-			   it'll remove structure from a sync_queue too. */
-			g_thread_join (thread);
-		} else {
-			g_hash_table_remove (sync_queue, pFile);
-		}
-
-		if (data) {
-			static gboolean no_sync_on_close = FALSE, iKnow = FALSE;
-
-			if (!iKnow) {
-				iKnow = TRUE;
-				no_sync_on_close = getenv ("CAMEL_NO_SYNC_ON_CLOSE") != NULL;
-			}
-
-			/* do not block queue on while syncing */
-			UnlockQueue ();
-
-			if (!no_sync_on_close) {
-				/* sync on close */
-				call_old_file_Sync (pFile, sync_flags);
-			}
-
-			g_free (data);
-		}
-	} else {
-		UnlockQueue ();
-	}
-}
-
-#define def_subclassed(_nm, _params, _call)			\
-static int							\
-camel_sqlite3_file_ ## _nm _params				\
-{								\
-	struct CamelSqlite3File *cFile;				\
-								\
-	g_return_val_if_fail (old_vfs != NULL, SQLITE_ERROR);	\
-	g_return_val_if_fail (pFile != NULL, SQLITE_ERROR);	\
-								\
-	cFile = (struct CamelSqlite3File *) pFile;		\
-	g_return_val_if_fail (cFile->old_vfs_file->pMethods != NULL, SQLITE_ERROR);	\
-	return cFile->old_vfs_file->pMethods->_nm _call;	\
-}
-
-def_subclassed (xRead, (sqlite3_file *pFile, void *pBuf, int iAmt, sqlite3_int64 iOfst), (cFile->old_vfs_file, pBuf, iAmt, iOfst))
-def_subclassed (xWrite, (sqlite3_file *pFile, const void *pBuf, int iAmt, sqlite3_int64 iOfst), (cFile->old_vfs_file, pBuf, iAmt, iOfst))
-def_subclassed (xTruncate, (sqlite3_file *pFile, sqlite3_int64 size), (cFile->old_vfs_file, size))
-def_subclassed (xFileSize, (sqlite3_file *pFile, sqlite3_int64 *pSize), (cFile->old_vfs_file, pSize))
-def_subclassed (xLock, (sqlite3_file *pFile, int lockType), (cFile->old_vfs_file, lockType))
-def_subclassed (xUnlock, (sqlite3_file *pFile, int lockType), (cFile->old_vfs_file, lockType))
-#if SQLITE_VERSION_NUMBER < 3006000
-def_subclassed (xCheckReservedLock, (sqlite3_file *pFile), (cFile->old_vfs_file))
-#else
-def_subclassed (xCheckReservedLock, (sqlite3_file *pFile, int *pResOut), (cFile->old_vfs_file, pResOut))
-#endif
-def_subclassed (xFileControl, (sqlite3_file *pFile, int op, void *pArg), (cFile->old_vfs_file, op, pArg))
-def_subclassed (xSectorSize, (sqlite3_file *pFile), (cFile->old_vfs_file))
-def_subclassed (xDeviceCharacteristics, (sqlite3_file *pFile), (cFile->old_vfs_file))
-
-#undef def_subclassed
-
-static int
-camel_sqlite3_file_xClose (sqlite3_file *pFile)
-{
-	struct CamelSqlite3File *cFile;
-	int res;
-
-	g_return_val_if_fail (old_vfs != NULL, SQLITE_ERROR);
-	g_return_val_if_fail (pFile != NULL, SQLITE_ERROR);
-
-	dequeue_sync (pFile);
-
-	cFile = (struct CamelSqlite3File *) pFile;
-	if (cFile->old_vfs_file->pMethods)
-		res = cFile->old_vfs_file->pMethods->xClose (cFile->old_vfs_file);
-	else
-		res = SQLITE_OK;
-
-	g_free (cFile->old_vfs_file);
-	cFile->old_vfs_file = NULL;
-
-	return res;
-}
-
-static int 
-camel_sqlite3_file_xSync (sqlite3_file *pFile, int flags)
-{
-	g_return_val_if_fail (old_vfs != NULL, SQLITE_ERROR);
-	g_return_val_if_fail (pFile != NULL, SQLITE_ERROR);
-
-	queue_sync (pFile, flags);
-
-	return SQLITE_OK;
-}
-
-static int
-camel_sqlite3_vfs_xOpen (sqlite3_vfs *pVfs, const char *zPath, sqlite3_file *pFile, int flags, int *pOutFlags)
-{
-	static sqlite3_io_methods io_methods = {0};
-	struct CamelSqlite3File *cFile;
-	int res;
-
-	g_return_val_if_fail (old_vfs != NULL, -1);
-	g_return_val_if_fail (pFile != NULL, -1);
-
-	cFile = (struct CamelSqlite3File *)pFile;
-	cFile->old_vfs_file = g_malloc0 (old_vfs->szOsFile);
-
-	res = old_vfs->xOpen (old_vfs, zPath, cFile->old_vfs_file, flags, pOutFlags);
-
-	g_static_rec_mutex_lock (&only_once_lock);
-
-	/* cFile->old_vfs_file->pMethods is NULL when open failed for some reason,
-	   thus do not initialize our structure when do not know the version */
-	if (io_methods.xClose == NULL && cFile->old_vfs_file->pMethods) {
-		/* initialize our subclass function only once */
-		io_methods.iVersion = cFile->old_vfs_file->pMethods->iVersion;
-
-		#define use_subclassed(x) io_methods.x = camel_sqlite3_file_ ## x
-		use_subclassed (xClose);
-		use_subclassed (xRead);
-		use_subclassed (xWrite);
-		use_subclassed (xTruncate);
-		use_subclassed (xSync);
-		use_subclassed (xFileSize);
-		use_subclassed (xLock);
-		use_subclassed (xUnlock);
-		use_subclassed (xCheckReservedLock);
-		use_subclassed (xFileControl);
-		use_subclassed (xSectorSize);
-		use_subclassed (xDeviceCharacteristics);
-		#undef use_subclassed
-	}
-
-	g_static_rec_mutex_unlock (&only_once_lock);
-
-	cFile->parent.pMethods = &io_methods;
-
-	return res;
-}
-
-static void
-init_sqlite_vfs (void)
-{
-	static sqlite3_vfs vfs = { 0 };
-
-	g_static_rec_mutex_lock (&only_once_lock);
-	if (old_vfs) {
-		g_static_rec_mutex_unlock (&only_once_lock);
-		return;
-	}
-
-	old_vfs = sqlite3_vfs_find (NULL);
-	if (!old_vfs) {
-		g_static_rec_mutex_unlock (&only_once_lock);
-		g_return_if_fail (old_vfs != NULL);
-		return;
-	}
-
-	memcpy (&vfs, old_vfs, sizeof (sqlite3_vfs));
-
-	vfs.szOsFile = sizeof (struct CamelSqlite3File);
-	vfs.zName = "camel_sqlite3_vfs";
-	vfs.xOpen = camel_sqlite3_vfs_xOpen;
-
-	sqlite3_vfs_register (&vfs, 1);
-
-	g_static_rec_mutex_unlock (&only_once_lock);
-}
-
 #define d(x) if (camel_debug("sqlite")) x
 #define START(stmt) 	if (camel_debug("dbtime")) { g_print ("\n===========\nDB SQL operation [%s] started\n", stmt); if (!cdb->priv->timer) { cdb->priv->timer = g_timer_new (); } else { g_timer_reset(cdb->priv->timer);} }
 #define END 	if (camel_debug("dbtime")) { g_timer_stop (cdb->priv->timer); g_print ("DB Operation ended. Time Taken : %f\n###########\n", g_timer_elapsed (cdb->priv->timer, NULL)); }
-#define STARTTS(stmt) 	if (camel_debug("dbtimets")) { g_print ("\n===========\nDB SQL operation [%s] started\n", stmt); if (!cdb->priv->timer) { cdb->priv->timer = g_timer_new (); } else { g_timer_reset(cdb->priv->timer);} }
-#define ENDTS 	if (camel_debug("dbtimets")) { g_timer_stop (cdb->priv->timer); g_print ("DB Operation ended. Time Taken : %f\n###########\n", g_timer_elapsed (cdb->priv->timer, NULL)); }
-
 
 struct _CamelDBPrivate {
 	GTimer *timer;
@@ -413,8 +47,6 @@ struct _CamelDBPrivate {
 
 static GStaticRecMutex trans_lock = G_STATIC_REC_MUTEX_INIT;	
 
-static int write_mir (CamelDB *cdb, const char *folder_name, CamelMIRecord *record, CamelException *ex, gboolean delete_old_record);
-
 static int 
 cdb_sql_exec (sqlite3 *db, const char* stmt, CamelException *ex) 
 {
@@ -458,8 +90,6 @@ camel_db_open (const char *path, CamelException *ex)
 	char *cache;
 	int ret;
 
-	init_sqlite_vfs ();
-
 	CAMEL_DB_USE_SHARED_CACHE;
 	
 	ret = sqlite3_open(path, &db);
@@ -494,13 +124,8 @@ camel_db_open (const char *path, CamelException *ex)
 		cache = g_strdup ("PRAGMA cache_size=100");
 
 	camel_db_command (cdb, cache, NULL);
-	g_free (cache);
-	if (g_getenv("CAMEL_SQLITE_IN_MEMORY") != NULL) {
-		/* Optionally turn off Journaling, this gets over fsync issues, but could be risky */
-		camel_db_command (cdb, "PRAGMA main.journal_mode = off", NULL);
-		camel_db_command (cdb, "PRAGMA temp_store = memory", NULL);
-	}
 
+	g_free (cache);
 
 	sqlite3_busy_timeout (cdb->db, CAMEL_DB_SLEEP_INTERVAL);
 
@@ -569,8 +194,6 @@ camel_db_begin_transaction (CamelDB *cdb, CamelException *ex)
 		g_static_rec_mutex_lock (&trans_lock);
 
 	g_mutex_lock (cdb->lock);
-	STARTTS("BEGIN");
-
 	return (cdb_sql_exec (cdb->db, "BEGIN", ex));
 }
 
@@ -581,8 +204,9 @@ camel_db_end_transaction (CamelDB *cdb, CamelException *ex)
 	if (!cdb)
 		return -1;
 
+	START("COMMIT");
 	ret = cdb_sql_exec (cdb->db, "COMMIT", ex);
-	ENDTS;
+	END;
 	g_mutex_unlock (cdb->lock);
 	if (g_getenv("SQLITE_TRANSLOCK"))
 		g_static_rec_mutex_unlock (&trans_lock);
@@ -625,7 +249,7 @@ camel_db_transaction_command (CamelDB *cdb, GSList *qry_list, CamelException *ex
 		return -1;
 
 	g_mutex_lock (cdb->lock);
-	STARTTS("BEGIN");
+	START("BEGIN");
 	ret = cdb_sql_exec (cdb->db, "BEGIN", ex);
 	if (ret)
 		goto end;
@@ -640,7 +264,7 @@ camel_db_transaction_command (CamelDB *cdb, GSList *qry_list, CamelException *ex
 	}
 
 	ret = cdb_sql_exec (cdb->db, "COMMIT", ex);
-	ENDTS;
+	END;
 end:
 	g_mutex_unlock (cdb->lock);
 	return ret;
@@ -814,7 +438,7 @@ camel_db_count_total_message_info (CamelDB *cdb, const char *table_name, guint32
 	if (!cdb)
 		return -1;
 	
-	query = sqlite3_mprintf ("SELECT COUNT (*) FROM %Q where read=0 or read=1", table_name);
+	query = sqlite3_mprintf ("SELECT COUNT (*) FROM %Q", table_name);
 
 	ret = camel_db_count_message_info (cdb, query, count, ex);
 	sqlite3_free (query);
@@ -937,53 +561,6 @@ camel_db_delete_uid_from_vfolder_transaction (CamelDB *db, char *folder_name, ch
 	return ret;
 }
 
-struct _db_data_uids_flags {
-	GPtrArray *uids;
-	GPtrArray *flags;
-};
-static int
-read_uids_flags_callback (void *ref, int ncol, char ** cols, char ** name)
-{
-	struct _db_data_uids_flags *data= (struct _db_data_uids_flags *) ref;
-	 
-	int i;
-	for (i = 0; i < ncol; ++i) {
-		if (!strcmp (name [i], "uid"))
-			g_ptr_array_add (data->uids, (char *) (camel_pstring_strdup(cols [i])));
-		else if (!strcmp (name [i], "flags"))
-			g_ptr_array_add (data->flags, GUINT_TO_POINTER(strtoul (cols [i], NULL, 10)));
-	}
-	 
-	 return 0;
-}
-
-int
-camel_db_get_folder_uids_flags (CamelDB *db, char *folder_name, char *sort_by, char *collate, GPtrArray *summary, GHashTable *table, CamelException *ex)
-{
-	 GPtrArray *uids = summary;
-	 GPtrArray *flags = g_ptr_array_new ();
-	 char *sel_query;
-	 int ret;
-	 struct _db_data_uids_flags data;
-	 int i;
-	
-	 data.uids = uids;
-	 data.flags = flags;
-
-
-	 sel_query = sqlite3_mprintf("SELECT uid,flags FROM %Q%s%s%s%s", folder_name, sort_by ? " order by " : "", sort_by ? sort_by: "", (sort_by && collate) ? " collate " : "", (sort_by && collate) ? collate : "");	 
-
-	 ret = camel_db_select (db, sel_query, read_uids_flags_callback, &data, ex);
-	 sqlite3_free (sel_query);
-
-	 for (i=0; i<uids->len; i++) {
-		 g_hash_table_insert (table, uids->pdata[i], flags->pdata[i]);
-	 }
-
-	 g_ptr_array_free (flags, TRUE);
-	 return ret;
-}
-
 static int
 read_uids_callback (void *ref, int ncol, char ** cols, char ** name)
 {
@@ -1090,8 +667,9 @@ camel_db_get_vuids_from_vfolder (CamelDB *db, char *folder_name, char *filter, C
 
 	 if (cond)
 		  sqlite3_free (cond);
-	 #warning "handle return values"
-	 #warning "No The caller should parse the ex in case of NULL returns" 
+	 /* FIXME[disk-summary] handle return values */
+	 /* FIXME[disk-summary] No The caller should parse the ex in case
+	 *                      of NULL returns */
 	 array = g_ptr_array_new ();
 	 camel_db_select (db, sel_query, read_vuids_callback, array, ex);
 	 sqlite3_free (sel_query);
@@ -1188,32 +766,16 @@ camel_db_prepare_message_info_table (CamelDB *cdb, const char *folder_name, Came
 	return ret;
 }
 
-
-int 
-camel_db_write_fresh_message_info_record (CamelDB *cdb, const char *folder_name, CamelMIRecord *record, CamelException *ex)
-{
-	return write_mir (cdb, folder_name, record, ex, FALSE);
-}
-
-
 int
 camel_db_write_message_info_record (CamelDB *cdb, const char *folder_name, CamelMIRecord *record, CamelException *ex)
-{
-	return write_mir (cdb, folder_name, record, ex, TRUE);
-}
-
-static int 
-write_mir (CamelDB *cdb, const char *folder_name, CamelMIRecord *record, CamelException *ex, gboolean delete_old_record)
 {
 	int ret;
 	char *del_query;
 	char *ins_query;
 
-	/* FIXME: We should migrate from this DELETE followed by INSERT model to an INSERT OR REPLACE model as pointed out by pvanhoof */
-
 	/* NB: UGLIEST Hack. We can't modify the schema now. We are using msg_security (an unsed one to notify of FLAGGED/Dirty infos */
 
-	ins_query = sqlite3_mprintf ("INSERT OR REPLACE INTO %Q VALUES (%Q, %d, %d, %d, %d, %d, %d, %d, %d, %d, %d, %ld, %ld, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q )", 
+	ins_query = sqlite3_mprintf ("INSERT INTO %Q VALUES (%Q, %d, %d, %d, %d, %d, %d, %d, %d, %d, %d, %ld, %ld, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q, %Q )", 
 			folder_name, record->uid, record->flags,
 			record->msg_type, record->read, record->deleted, record->replied,
 			record->important, record->junk, record->attachment, record->dirty,
@@ -1224,8 +786,7 @@ write_mir (CamelDB *cdb, const char *folder_name, CamelMIRecord *record, CamelEx
 			record->part, record->labels, record->usertags,
 			record->cinfo, record->bdata);
 
-	//if (delete_old_record)
-	//		del_query = sqlite3_mprintf ("DELETE FROM %Q WHERE uid = %Q", folder_name, record->uid);
+	del_query = sqlite3_mprintf ("DELETE FROM %Q WHERE uid = %Q", folder_name, record->uid);
 
 #if 0
 	char *upd_query;
@@ -1235,14 +796,12 @@ write_mir (CamelDB *cdb, const char *folder_name, CamelMIRecord *record, CamelEx
 	g_free (upd_query);
 #else
 
-	//if (delete_old_record)
-	//		ret = camel_db_add_to_transaction (cdb, del_query, ex);
+	ret = camel_db_add_to_transaction (cdb, del_query, ex);
 	ret = camel_db_add_to_transaction (cdb, ins_query, ex);
 
 #endif
 
-	//if (delete_old_record)
-	//		sqlite3_free (del_query);
+	sqlite3_free (del_query);
 	sqlite3_free (ins_query);
 
 	return ret;
@@ -1430,9 +989,6 @@ cdb_delete_ids (CamelDB *cdb, const char * folder_name, GSList *uids, char *uid_
 int
 camel_db_delete_uids (CamelDB *cdb, const char * folder_name, GSList *uids, CamelException *ex)
 {
-	if(!uids || !uids->data)
-		return 0;
-
 	return cdb_delete_ids (cdb, folder_name, uids, "", "uid", ex);
 }
 
@@ -1596,39 +1152,3 @@ camel_db_migrate_vfolders_to_14 (CamelDB *cdb, const char *folder, CamelExceptio
 	CAMEL_DB_RELEASE_SQLITE_MEMORY;
 	return ret;		
 }
-
-int camel_db_start_in_memory_transactions (CamelDB *cdb, CamelException *ex)
-{
-	int ret;
-	char *cmd = sqlite3_mprintf ("ATTACH DATABASE ':memory:' AS %s", CAMEL_DB_IN_MEMORY_DB);
-
-	ret = camel_db_command (cdb, cmd, ex);
-	sqlite3_free (cmd);
-
-	cmd = sqlite3_mprintf ("CREATE TEMPORARY TABLE %Q (  uid TEXT PRIMARY KEY , flags INTEGER , msg_type INTEGER , read INTEGER , deleted INTEGER , replied INTEGER , important INTEGER , junk INTEGER , attachment INTEGER , msg_security INTEGER , size INTEGER , dsent NUMERIC , dreceived NUMERIC , subject TEXT , mail_from TEXT , mail_to TEXT , mail_cc TEXT , mlist TEXT , followup_flag TEXT , followup_completed_on TEXT , followup_due_by TEXT , part TEXT , labels TEXT , usertags TEXT , cinfo TEXT , bdata TEXT )", CAMEL_DB_IN_MEMORY_TABLE);
-	ret = camel_db_command (cdb, cmd, ex);
-	if (ret != 0 )
-		abort ();
-	sqlite3_free (cmd);
-	
-	return ret;
-}
-
-int camel_db_flush_in_memory_transactions (CamelDB *cdb, const char * folder_name, CamelException *ex)
-{
-	int ret;
-	char *cmd = sqlite3_mprintf ("INSERT INTO %Q SELECT * FROM %Q", folder_name, CAMEL_DB_IN_MEMORY_TABLE);
-
-	ret = camel_db_command (cdb, cmd, ex);
-	sqlite3_free (cmd);
-
-	cmd = sqlite3_mprintf ("DROP TABLE %Q", CAMEL_DB_IN_MEMORY_TABLE);
-	ret = camel_db_command (cdb, cmd, ex);
-	sqlite3_free (cmd);
-
-	cmd = sqlite3_mprintf ("DETACH %Q", CAMEL_DB_IN_MEMORY_DB);
-	ret = camel_db_command (cdb, cmd, ex);
-	sqlite3_free (cmd);
-
-	return ret;
-}
