@@ -171,61 +171,24 @@ vee_info_set_user_tag(CamelMessageInfo *mi, const char *name, const char *value)
 	return res;
 }
 
-void
-camel_vee_summary_load_check_unread_vfolder (CamelVeeSummary *vs)
-{
-	static int only_once = FALSE;
-	static char *exp = NULL;
-	char *meta;
-	gboolean hacked_unread_folder = FALSE;
-	CamelVeeFolder *vf = (CamelVeeFolder *) ((CamelFolderSummary *)vs)->folder;
-
-	/* HACK: Ugliest of all hacks. Its virtually not possible now
-	 * to maintain counts and the non matching uids of unread vfolder here.
-	 * So, I hardcode unread vfolder expression and hack it. */
-	if (!only_once) {
-		exp =  g_getenv("CAMEL_VFOLDER_UNREAD_EXP") ? g_strcompress(g_getenv("CAMEL_VFOLDER_UNREAD_EXP")) : NULL;
-		only_once = TRUE;
-	}
-
-	if (!exp || !*exp)
-		exp = g_strcompress(unread_str);
-
-	if (vf->expression && strstr(exp, vf->expression) &&  (vf->flags & CAMEL_STORE_VEE_FOLDER_SPECIAL) == 0)
-		hacked_unread_folder = TRUE;
-
-	meta = camel_object_meta_get (vf, "vfolder:unread");
-	if (!hacked_unread_folder && meta && strcmp (meta, "true") == 0)
-		hacked_unread_folder = TRUE;
-	g_free(meta);
-
-	if (hacked_unread_folder)
-		vf->priv->unread_vfolder = 1;
-	else
-		vf->priv->unread_vfolder = 0;
-}
-
 static gboolean
 vee_info_set_flags(CamelMessageInfo *mi, guint32 flags, guint32 set)
 {
 	int res = FALSE;
 	CamelVeeFolder *vf = (CamelVeeFolder *)mi->summary->folder;
+	const char *exp = g_getenv("CAMEL_VFOLDER_UNREAD_EXP");
 	gboolean hacked_unread_folder = FALSE;
 
+	/* HACK: Ugliest of all hacks. Its virtually not possible now
+	 * to maintain counts and the non matching uids of unread vfolder here.
+	 * So, I hardcode unread vfolder expression and hack it. */
+	if (!exp || !*exp)
+		exp = unread_str;
 	if (camel_debug("vfolderexp"))
 		printf("Expression for vfolder '%s' is '%s'\n", mi->summary->folder->full_name, g_strescape(vf->expression, ""));
 
-	if (vf->priv->unread_vfolder == -1)
-		camel_vee_summary_load_check_unread_vfolder (mi->summary);
-
-	if (vf->priv->unread_vfolder == 1)
+	if (strstr(exp, vf->expression) &&  (vf->flags & CAMEL_STORE_VEE_FOLDER_SPECIAL) == 0)
 		hacked_unread_folder = TRUE;
-	else {
-		char *meta = camel_object_meta_get (mi->summary->folder, "vfolder:unread");
-		if (meta && strcmp (meta, "true") == 0)
-			hacked_unread_folder = TRUE;
-		g_free(meta);
-	}
 
 	if (mi->uid) {
 		guint32 old_visible, old_unread, old_deleted, old_junked, old_junked_not_deleted;
@@ -262,11 +225,11 @@ vee_info_set_flags(CamelMessageInfo *mi, guint32 flags, guint32 set)
 			vsummary->fake_visible_count = mi->summary->visible_count;
 
 		/* Keep the summary in sync */
-		//mi->summary->unread_count += unread - old_unread;
-		//mi->summary->deleted_count += deleted - old_deleted;
-		//mi->summary->junk_count += junked - old_junked;
-		//mi->summary->junk_not_deleted_count += junked_not_deleted - old_junked_not_deleted;
-		//mi->summary->visible_count += visible - old_visible;
+		mi->summary->unread_count += unread - old_unread;
+		mi->summary->deleted_count += deleted - old_deleted;
+		mi->summary->junk_count += junked - old_junked;
+		mi->summary->junk_not_deleted_count += junked_not_deleted - old_junked_not_deleted;
+		mi->summary->visible_count += visible - old_visible;
 
 		if (vsummary->fake_visible_count || hacked_unread_folder)
 			vsummary->fake_visible_count += visible - old_visible;
@@ -308,7 +271,8 @@ message_info_from_uid (CamelFolderSummary *s, const char *uid)
 {
 	CamelMessageInfo *info;
 
-	#warning "too bad design. Need to peek it from cfs instead of hacking ugly like this"
+	/* FIXME[disk-summary] too bad design. Need to peek it from cfs
+	 * instead of hacking ugly like this */
 	CAMEL_SUMMARY_LOCK(s, summary_lock);
 	CAMEL_SUMMARY_LOCK(s, ref_lock);
 
@@ -429,7 +393,7 @@ camel_vee_summary_new(CamelFolder *parent)
 	 * VTrash instead of .#evolution/Junk-or-whatever */
 	camel_db_create_vfolder (parent->parent_store->cdb_w, parent->full_name, NULL);
 
-	#warning "handle excep and ret"
+	/* FIXME[disk-summary] handle excep and ret */
 	camel_folder_summary_header_load_from_db ((CamelFolderSummary *)s, parent->parent_store, parent->full_name, NULL);
 	return &s->summary;
 }
@@ -454,7 +418,7 @@ camel_vee_summary_add(CamelVeeSummary *s, CamelFolderSummary *summary, const cha
 {
 	CamelVeeMessageInfo *mi;
 	char *vuid;
-	GHashTable * fcache;
+
 	vuid = g_malloc(strlen(uid)+9);
 	memcpy(vuid, hash, 8);
 	strcpy(vuid+8, uid);
@@ -477,8 +441,6 @@ camel_vee_summary_add(CamelVeeSummary *s, CamelFolderSummary *summary, const cha
 
 	mi = (CamelVeeMessageInfo *)camel_message_info_new(&s->summary);
 	mi->summary = summary;
-	fcache = camel_folder_summary_get_flag_cache(summary);
-	mi->old_flags = GPOINTER_TO_UINT(g_hash_table_lookup (fcache, uid));
 	/* We would do lazy loading of flags, when the folders are loaded to memory through folder_reloaded signal */
 	camel_object_ref (summary);
 	mi->info.uid = (char *) camel_pstring_strdup (vuid);
