@@ -4,7 +4,7 @@
 /*
  *  Authors: Jeffrey Stedfast <fejj@ximian.com>
  *
- *  Copyright 2000 Ximian, Inc. (www.ximian.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -44,6 +44,8 @@ CamelProviderConfEntry imap_conf_entries[] = {
 	  N_("Checking for New Mail") },
 	{ CAMEL_PROVIDER_CONF_CHECKBOX, "check_all", NULL,
 	  N_("C_heck for new messages in all folders"), "1" },
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "check_lsub", NULL,
+	  N_("Ch_eck for new messages in subscribed folders"), "0" },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
 #ifndef G_OS_WIN32
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "cmdsection", NULL,
@@ -96,10 +98,10 @@ static CamelProvider imap_provider = {
 
 CamelServiceAuthType camel_imap_password_authtype = {
 	N_("Password"),
-
+	
 	N_("This option will connect to the IMAP server using a "
 	   "plaintext password."),
-
+	
 	"",
 	TRUE
 };
@@ -134,7 +136,7 @@ imap_url_hash (gconstpointer key)
 	add_hash (&hash, u->authmech);
 	add_hash (&hash, u->host);
 	hash ^= u->port;
-
+	
 	return hash;
 }
 
@@ -147,10 +149,10 @@ check_equal (char *s1, char *s2)
 		else
 			return FALSE;
 	}
-
+	
 	if (s2 == NULL)
 		return FALSE;
-
+	
 	return strcmp (s1, s2) == 0;
 }
 
@@ -158,7 +160,7 @@ static int
 imap_url_equal (gconstpointer a, gconstpointer b)
 {
 	const CamelURL *u1 = a, *u2 = b;
-
+	
 	return check_equal (u1->protocol, u2->protocol)
 		&& check_equal (u1->user, u2->user)
 		&& check_equal (u1->authmech, u2->authmech)
